@@ -1,6 +1,4 @@
-from pard.raw_python_dictionaries import make_grantham_dict
-
-GRANTHAM_DICT: dict[tuple[str, str], int] = make_grantham_dict()
+import pard.raw_python_dictionaries
 
 def grantham(amino_acid_1: str, amino_acid_2: str) -> int:
     """
@@ -8,4 +6,4 @@ def grantham(amino_acid_1: str, amino_acid_2: str) -> int:
     :param amino_acid_2: 1 letter code of the third amino acid
     :return: An integer representing the Grantham distance between aa_1 and amino_acid_2
     """
-    return GRANTHAM_DICT[(amino_acid_1, amino_acid_2)]
+    return pard.raw_python_dictionaries.GRANTHAM_DICT[(amino_acid_1, amino_acid_2)]
